psychopy_ext.exp.Task.create_fixation — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.Task.create_fixation

`Task.` `create_fixation`(shape='complex', color='black', size=0.2)

  Creates a fixation spot.

  Kwargs: | shape: {‘dot’, ‘complex’} (default: ‘complex’) Choose the type of fixation: dot: a simple fixation dot (.2 deg visual angle) complex: the ‘best’ fixation shape by Thaler et al., 2012 which looks like a combination of s bulls eye and cross hair (outer diameter: .6 deg, inner diameter: .2 deg). Note that it is constructed by superimposing two rectangles on a disk, so if non-uniform background will not be visible. color (str, default: ‘black’) Fixation color.